@@ -1,6 +1,7 @@
 """Test Api class"""
 
 from collections import OrderedDict
+import json
 
 import pytest
 
@@ -25,6 +26,22 @@ class TestAPISpec:
             assert 'produces' not in spec
             assert 'consumes' not in spec
 
+    def test_apispec_print_openapi_doc(self, app):
+        api = Api(app)
+        result = app.test_cli_runner().invoke(args=('openapi', 'print'))
+        assert result.exit_code == 0
+        assert json.loads(result.output) == api.spec.to_dict()
+
+    def test_apispec_write_openapi_doc(self, app, tmp_path):
+        output_file = tmp_path / 'openapi.json'
+        api = Api(app)
+        result = app.test_cli_runner().invoke(
+            args=('openapi', 'write', str(output_file))
+        )
+        assert result.exit_code == 0
+        with open(output_file) as output:
+            assert json.loads(output.read()) == api.spec.to_dict()
+
 
 class TestAPISpecServeDocs:
     """Test APISpec class docs serving features"""
